@@ -16,89 +16,11 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <assert.h>
 
 #include "util.h"
 #include "funcs_gga.c"
 #include "funcs_hyb_gga.c"
 
-/* initialization */
-int XC(gga_init)(XC(func_type) *func, const XC(func_info_type) *info, int nspin)
-{
-  assert(func != NULL);
-
-  /* initialize structure */
-  func->info   = info;
-  func->nspin  = nspin;
-  func->params = NULL;
-  func->func   = 0;
-
-  func->n_func_aux = 0;
-  func->func_aux   = NULL;
-  func->mix_coef   = NULL;
-  func->cam_omega = func->cam_alpha = func->cam_beta = 0.0;
-
-  /* initialize spin counters */
-  func->n_zk  = 1;
-  func->n_rho = func->n_vrho = func->nspin;
-  if(func->nspin == XC_UNPOLARIZED){
-    func->n_sigma  = func->n_vsigma = 1;
-    func->n_v2rho2 = func->n_v2rhosigma  = func->n_v2sigma2 = 1;
-    func->n_v3rho3 = func->n_v3rho2sigma = func->n_v3rhosigma2 = func->n_v3sigma3 = 1;
-  }else{
-    func->n_sigma      = func->n_vsigma = 3;
-    func->n_v2rho2     = 3;
-    func->n_v2rhosigma = func->n_v2sigma2 = 6;
-
-    func->n_v3rho3      = 4;
-    func->n_v3rho2sigma = 9;
-    func->n_v3rhosigma2 = 12;
-    func->n_v3sigma3    = 10;
-  }
-
-  /* see if we need to initialize the functional */
-  if(func->info->init != NULL)
-    func->info->init(func);
-  return 0;
-}
-
-
-/* Termination */
-void XC(gga_end)(XC(func_type) *func)
-{
-  assert(func != NULL);
-
-  /* call internal termination routine */
-  if(func->info->end != NULL)
-    func->info->end(func);
-
-  /* terminate any auxiliary functional */
-  if(func->n_func_aux > 0){
-    int ii;
-
-    for(ii=0; ii<func->n_func_aux; ii++){
-      XC(func_end)(func->func_aux[ii]);
-      free(func->func_aux[ii]);
-    }
-    free(func->func_aux);
-    func->n_func_aux = 0;
-  }
-
-  if(func->mix_coef != NULL){
-    free(func->mix_coef);
-    func->mix_coef = NULL;
-  }
-
-  /* deallocate any used parameter */
-  if(func->params != NULL){
-    free(func->params);
-    func->params = NULL;
-  }
-}
-
 /* Some useful formulas:
 
    sigma_st          = grad rho_s . grad rho_t
@@ -133,10 +55,10 @@ if nspin == 2
    v3sigma(10)     = (uu_uu_uu, uu_uu_ud, uu_uu_dd, uu_ud_ud, uu_ud_dd, uu_dd_dd, ud_ud_ud, ud_ud_dd, ud_dd_dd, dd_dd_dd)
    
 */
-void XC(gga)(const XC(func_type) *func, int np, const FLOAT *rho, const FLOAT *sigma,
-	     FLOAT *zk, FLOAT *vrho, FLOAT *vsigma,
-	     FLOAT *v2rho2, FLOAT *v2rhosigma, FLOAT *v2sigma2,
-	     FLOAT *v3rho3, FLOAT *v3rho2sigma, FLOAT *v3rhosigma2, FLOAT *v3sigma3)
+void xc_gga(const xc_func_type *func, int np, const double *rho, const double *sigma,
+	     double *zk, double *vrho, double *vsigma,
+	     double *v2rho2, double *v2rhosigma, double *v2sigma2,
+	     double *v3rho3, double *v3rho2sigma, double *v3rhosigma2, double *v3sigma3)
 {
   assert(func != NULL);
   
@@ -167,30 +89,30 @@ void XC(gga)(const XC(func_type) *func, int np, const FLOAT *rho, const FLOAT *s
 
   /* initialize output to zero */
   if(zk != NULL)
-    memset(zk, 0, func->n_zk*np*sizeof(FLOAT));
+    memset(zk, 0, func->n_zk*np*sizeof(double));
 
   if(vrho != NULL){
     assert(vsigma != NULL);
     
-    memset(vrho,   0, func->n_vrho  *np*sizeof(FLOAT));
-    memset(vsigma, 0, func->n_vsigma*np*sizeof(FLOAT));
+    memset(vrho,   0, func->n_vrho  *np*sizeof(double));
+    memset(vsigma, 0, func->n_vsigma*np*sizeof(double));
   }
 
   if(v2rho2 != NULL){
     assert(v2rhosigma!=NULL && v2sigma2!=NULL);
 
-    memset(v2rho2,     0, func->n_v2rho2    *np*sizeof(FLOAT));
-    memset(v2rhosigma, 0, func->n_v2rhosigma*np*sizeof(FLOAT));
-    memset(v2sigma2,   0, func->n_v2sigma2  *np*sizeof(FLOAT));
+    memset(v2rho2,     0, func->n_v2rho2    *np*sizeof(double));
+    memset(v2rhosigma, 0, func->n_v2rhosigma*np*sizeof(double));
+    memset(v2sigma2,   0, func->n_v2sigma2  *np*sizeof(double));
   }
 
   if(v3rho3 != NULL){
     assert(v3rho2sigma!=NULL && v3rhosigma2!=NULL && v3sigma3!=NULL);
 
-    memset(v3rho3,      0, func->n_v3rho3     *np*sizeof(FLOAT));
-    memset(v3rho2sigma, 0, func->n_v3rho2sigma*np*sizeof(FLOAT));
-    memset(v3rhosigma2, 0, func->n_v3rhosigma2*np*sizeof(FLOAT));
-    memset(v3sigma3,    0, func->n_v3sigma3   *np*sizeof(FLOAT));    
+    memset(v3rho3,      0, func->n_v3rho3     *np*sizeof(double));
+    memset(v3rho2sigma, 0, func->n_v3rho2sigma*np*sizeof(double));
+    memset(v3rhosigma2, 0, func->n_v3rhosigma2*np*sizeof(double));
+    memset(v3sigma3,    0, func->n_v3sigma3   *np*sizeof(double));    
   }
 
   /* call functional */
@@ -200,7 +122,7 @@ void XC(gga)(const XC(func_type) *func, int np, const FLOAT *rho, const FLOAT *s
 		    v3rho3, v3rho2sigma, v3rhosigma2, v3sigma3);
 
   if(func->mix_coef != NULL)
-    XC(mix_func)(func, np, rho, sigma, NULL, NULL, zk, vrho, vsigma, NULL, NULL,
+    xc_mix_func(func, np, rho, sigma, NULL, NULL, zk, vrho, vsigma, NULL, NULL,
 		 v2rho2, v2sigma2, NULL, NULL, v2rhosigma, NULL, NULL, NULL, NULL, NULL);
 
 }
@@ -208,40 +130,40 @@ void XC(gga)(const XC(func_type) *func, int np, const FLOAT *rho, const FLOAT *s
 /* specializations */
 /* returns only energy */
 inline void 
-XC(gga_exc)(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma, 
-	    FLOAT *zk)
+xc_gga_exc(const xc_func_type *p, int np, const double *rho, const double *sigma, 
+	    double *zk)
 {
-  XC(gga)(p, np, rho, sigma, zk, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+  xc_gga(p, np, rho, sigma, zk, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
 }
 
 /* returns only potential */
 inline void 
-XC(gga_vxc)(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma,
-	    FLOAT *vrho, FLOAT *vsigma)
+xc_gga_vxc(const xc_func_type *p, int np, const double *rho, const double *sigma,
+	    double *vrho, double *vsigma)
 {
-  XC(gga)(p, np, rho, sigma, NULL, vrho, vsigma, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+  xc_gga(p, np, rho, sigma, NULL, vrho, vsigma, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
 }
 
 /* returns both energy and potential (the most common call usually) */
 inline void 
-XC(gga_exc_vxc)(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma,
-		FLOAT *zk, FLOAT *vrho, FLOAT *vsigma)
+xc_gga_exc_vxc(const xc_func_type *p, int np, const double *rho, const double *sigma,
+		double *zk, double *vrho, double *vsigma)
 {
-  XC(gga)(p, np, rho, sigma, zk, vrho, vsigma, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+  xc_gga(p, np, rho, sigma, zk, vrho, vsigma, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
 }
 
 /* returns second derivatives */
 inline void 
-XC(gga_fxc)(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma,
-	    FLOAT *v2rho2, FLOAT *v2rhosigma, FLOAT *v2sigma2)
+xc_gga_fxc(const xc_func_type *p, int np, const double *rho, const double *sigma,
+	    double *v2rho2, double *v2rhosigma, double *v2sigma2)
 {
-  XC(gga)(p, np, rho, sigma, NULL, NULL, NULL, v2rho2, v2rhosigma, v2sigma2, NULL, NULL, NULL, NULL);
+  xc_gga(p, np, rho, sigma, NULL, NULL, NULL, v2rho2, v2rhosigma, v2sigma2, NULL, NULL, NULL, NULL);
 }
 
 /* returns third derivatives */
 inline void 
-XC(gga_kxc)(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma,
-	    FLOAT *v3rho3, FLOAT *v3rho2sigma, FLOAT *v3rhosigma2, FLOAT *v3sigma3)
+xc_gga_kxc(const xc_func_type *p, int np, const double *rho, const double *sigma,
+	    double *v3rho3, double *v3rho2sigma, double *v3rhosigma2, double *v3sigma3)
 {
-  XC(gga)(p, np, rho, sigma, NULL, NULL, NULL, NULL, NULL, NULL, v3rho3, v3rho2sigma, v3rhosigma2, v3sigma3);
+  xc_gga(p, np, rho, sigma, NULL, NULL, NULL, NULL, NULL, NULL, v3rho3, v3rho2sigma, v3rhosigma2, v3sigma3);
 }
