@@ -16,9 +16,6 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <assert.h>
 #include "util.h"
 
 #define XC_GGA_K_DK          516 /* DePristo and Kress                    */
@@ -28,14 +25,14 @@
 #define XC_GGA_K_ERNZERHOF   520 /* Ernzerhof */
 
 typedef struct{
-  FLOAT aa[5], bb[5];
+  double aa[5], bb[5];
 } gga_k_dk_params;
 
 static void 
-gga_k_dk_init(XC(func_type) *p)
+gga_k_dk_init(xc_func_type *p)
 {
   int i;
-  FLOAT ff, *aa, *bb;
+  double ff, *aa, *bb;
 
   assert(p->params == NULL);
   p->params = malloc(sizeof(gga_k_dk_params));
@@ -119,108 +116,81 @@ gga_k_dk_init(XC(func_type) *p)
   }
 }
 
+#include "maple2c/gga_k_dk.c"
 
-static inline void 
-func(const XC(func_type) *p, int order, FLOAT x, 
-     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
-{
-  FLOAT xx2, xx4, num, denom, dnum, ddenom, d2num, d2denom;
-  FLOAT *aa, *bb;
-
-  assert(p->params != NULL);
-  aa  = ((gga_k_dk_params *) (p->params))->aa;
-  bb  = ((gga_k_dk_params *) (p->params))->bb;
-
-  xx2 = x*x;
-  xx4 = xx2*xx2;
-
-  num   = aa[0] + aa[1]*xx2 + aa[2]*xx4 + aa[3]*xx2*xx4 + aa[4]*xx4*xx4;
-  denom = bb[0] + bb[1]*xx2 + bb[2]*xx4 + bb[3]*xx2*xx4 + bb[4]*xx4*xx4;
-
-  *f = num/denom;
-
-  if(order < 1) return;
-
-  dnum   = 2.0*aa[1]*x + 4.0*aa[2]*x*xx2 + 6.0*aa[3]*x*xx4 + 8.0*aa[4]*x*xx2*xx4;
-  ddenom = 2.0*bb[1]*x + 4.0*bb[2]*x*xx2 + 6.0*bb[3]*x*xx4 + 8.0*bb[4]*x*xx2*xx4;
-
-  *dfdx  = (dnum*denom - num*ddenom)/(denom*denom);
-  
-  if(order < 2) return;
-
-  d2num   = 2.0*aa[1] + 4.0*3.0*aa[2]*xx2 + 6.0*5.0*aa[3]*xx4 + 8.0*7.0*aa[4]*xx2*xx4;
-  d2denom = 2.0*bb[1] + 4.0*3.0*bb[2]*xx2 + 6.0*5.0*bb[3]*xx4 + 8.0*7.0*bb[4]*xx2*xx4;
-
-  *d2fdx2  = ((d2num*denom - num*d2denom)*denom - 2.0*ddenom*(dnum*denom - ddenom*num))/(denom*denom*denom);
-}
-
+#define func maple2c_func
 #define XC_KINETIC_FUNCTIONAL
 #include "work_gga_x.c"
 
-const XC(func_info_type) XC(func_info_gga_k_dk) = {
+const xc_func_info_type xc_func_info_gga_k_dk = {
   XC_GGA_K_DK,
   XC_KINETIC,
   "DePristo and Kress",
   XC_FAMILY_GGA,
   {&xc_ref_DePristo1987_438, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-25,
+  0, NULL, NULL,
   gga_k_dk_init,
   NULL, NULL,
   work_gga_k,
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_k_perdew) = {
+const xc_func_info_type xc_func_info_gga_k_perdew = {
   XC_GGA_K_PERDEW,
   XC_KINETIC,
   "Perdew",
   XC_FAMILY_GGA,
   {&xc_ref_Perdew1992_79, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-32,
+  0, NULL, NULL,
   gga_k_dk_init,
   NULL, NULL,
   work_gga_k,
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_k_vsk) = {
+const xc_func_info_type xc_func_info_gga_k_vsk = {
   XC_GGA_K_VSK,
   XC_KINETIC,
   "Vitos, Skriver, and Kollar",
   XC_FAMILY_GGA,
   {&xc_ref_Vitos1998_12611, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-25,
+  0, NULL, NULL,
   gga_k_dk_init,
   NULL, NULL,
   work_gga_k,
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_k_vjks) = {
+const xc_func_info_type xc_func_info_gga_k_vjks = {
   XC_GGA_K_VJKS,
   XC_KINETIC,
   "Vitos, Johansson, Kollar, and Skriver",
   XC_FAMILY_GGA,
   {&xc_ref_Vitos2000_052511, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-25,
+  0, NULL, NULL,
   gga_k_dk_init,
   NULL, NULL,
   work_gga_k,
   NULL
 };
 
-const XC(func_info_type) XC(func_info_gga_k_ernzerhof) = {
+const xc_func_info_type xc_func_info_gga_k_ernzerhof = {
   XC_GGA_K_ERNZERHOF,
   XC_KINETIC,
   "Ernzerhof",
   XC_FAMILY_GGA,
   {&xc_ref_Ernzerhof2000_59, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-25,
+  0, NULL, NULL,
   gga_k_dk_init,
   NULL, NULL,
   work_gga_k,
