@@ -16,52 +16,25 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <assert.h>
 #include "util.h"
 
 #define XC_GGA_K_MEYER        57 /* Meyer,  Wang, and Young */
 
-static inline void 
-func(const XC(func_type) *p, int order, FLOAT x, 
-     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
-{
-  FLOAT y, ll, lambda, dy, dlambda, d2lambda;
-
-  y = X2S*x/6.0;
-
-  ll     = LOG((1.0 + y)/ABS(1.0 - y));
-  lambda = 0.5*(1.0 + (1.0 - y*y)*ll/(2.0*y));
-
-  *f = 1.0 + lambda*x*x/(8.0*K_FACTOR_C);
-
-  if(order < 1) return;
-
-  dy = X2S/6.0;
-
-  dlambda = dy*(2.0*y - (1.0 + y*y)*ll)/(4.0*y*y);
-
-  *dfdx = (dlambda*x + 2.0*lambda)*x/(8.0*K_FACTOR_C);
-
-  if(order < 2) return;
-
-  d2lambda = dy*dy*(2.0*y/(y*y - 1.0) + ll)/(2.0*y*y*y);
-
-  *d2fdx2  = (d2lambda*x*x + 4.0*dlambda*x + 2.0*lambda)/(8.0*K_FACTOR_C);
-}
+#include "maple2c/gga_k_meyer.c"
 
+#define func maple2c_func
 #define XC_KINETIC_FUNCTIONAL
 #include "work_gga_x.c"
 
-const XC(func_info_type) XC(func_info_gga_k_meyer) = {
+const xc_func_info_type xc_func_info_gga_k_meyer = {
   XC_GGA_K_MEYER,
   XC_KINETIC,
   "Meyer,  Wang, and Young",
   XC_FAMILY_GGA,
   {&xc_ref_Meyer1976_898, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  5e-14,
+  0, NULL, NULL,
   NULL,
   NULL, NULL,
   work_gga_k,
