@@ -16,58 +16,24 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <stdio.h>
-#include <assert.h>
 #include "util.h"
 
 #define XC_GGA_X_MPBE         122 /* Adamo & Barone modification to PBE             */
 
+#include "maple2c/gga_x_mpbe.c"
 
-void XC(gga_x_mpbe_enhance)
-  (const XC(func_type) *p, int order, FLOAT x, 
-   FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
-{
-  static FLOAT a = 0.157;
-  static FLOAT c1 = 0.21951, c2 = -0.015;
-
-  FLOAT ss, ss2, f0, df0, d2f0, d3f0, f1;
-
-  ss  = X2S*x;
-  ss2 = ss*ss;
-
-  f1 = 1.0 + a*ss2;
-  f0 = ss2/f1;
-  *f = 1.0 + c1*f0 + c2*f0*f0;
-
-  if(order < 1) return;
-
-  df0 = DFRACTION(ss2, 2.0*ss, f1, 2.0*a*ss);
-
-  *dfdx  = X2S*(c1 + 2.0*c2*f0)*df0;
-
-  if(order < 2) return;
-
-  d2f0 = D2FRACTION(ss2, 2.0*ss, 2.0, f1, 2.0*a*ss, 2.0*a);
-  *d2fdx2 = X2S*X2S*((c1 + 2.0*c2*f0)*d2f0 + 2.0*c2*df0*df0);
-
-  if(order < 3) return;
-
-  d3f0 = D3FRACTION(ss2, 2.0*ss, 2.0, 0.0, f1, 2.0*a*ss, 2.0*a, 0.0);
-  *d3fdx3 = X2S*X2S*X2S*((c1 + 2.0*c2*f0)*d3f0 + 6.0*c2*df0*d2f0);
-}
-
-
-#define func XC(gga_x_mpbe_enhance)
+#define func maple2c_func
 #include "work_gga_x.c"
 
-const XC(func_info_type) XC(func_info_gga_x_mpbe) = {
+const xc_func_info_type xc_func_info_gga_x_mpbe = {
   XC_GGA_X_MPBE,
   XC_EXCHANGE,
   "Adamo & Barone modification to PBE",
   XC_FAMILY_GGA,
   {&xc_ref_Adamo2002_5933, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-21,
+  0, NULL, NULL,
   NULL, NULL, NULL,
   work_gga_x,
   NULL
