@@ -16,50 +16,24 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <stdio.h>
-#include <assert.h>
 #include "util.h"
 
 #define XC_GGA_X_PBEA  121 /* Madsen (PBE-like) */
 
-/* PBEA: see PBE for more details */
-static inline void 
-func(const XC(func_type) *p, int order, FLOAT x, 
-     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
-{
-  static const FLOAT kappa = 0.8040;
-  static const FLOAT mu = 0.00361218645365094697;
-  /* hard-coded alpha*/
-  static const FLOAT alpha = 0.52;
-
-  FLOAT f0, df0, d2f0;
-
-  f0 = 1.0 + mu*x*x/(alpha*kappa);
-  *f = 1.0 + kappa*(1.0 - POW(f0, -alpha));
-
-  if(order < 1) return;
-
-  df0 = 2.0*mu*x/(alpha*kappa);
-
-  *dfdx  = alpha*kappa*df0*POW(f0, -(alpha + 1.0));
-
-  if(order < 2) return;
-
-  d2f0 = 2.0*mu/(alpha*kappa);
-  *d2fdx2 = alpha*kappa*POW(f0, -alpha - 1.0)*
-    (d2f0 - (alpha + 1.0)*df0*df0/f0);
-}
+#include "maple2c/gga_x_pbea.c"
 
+#define func maple2c_func
 #include "work_gga_x.c"
 
-const XC(func_info_type) XC(func_info_gga_x_pbea) = {
+const xc_func_info_type xc_func_info_gga_x_pbea = {
   XC_GGA_X_PBEA,
   XC_EXCHANGE,
   "Madsen 07",
   XC_FAMILY_GGA,
   {&xc_ref_Madsen2007_195108, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-32,
+  0, NULL, NULL,
   NULL, NULL, NULL,
   work_gga_x,
   NULL
