@@ -16,9 +16,6 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <assert.h>
 #include "util.h"
 
 #define XC_GGA_XC_XLYP       166  /* XLYP functional */
@@ -27,88 +24,92 @@
 #define XC_GGA_XC_PBELYP1W   175  /* Functionals fitted for water */
 
 static void
-gga_xc_xlyp_init(XC(func_type) *p)
+gga_xc_xlyp_init(xc_func_type *p)
 {
   static int   funcs_id  [4] = {XC_LDA_X, XC_GGA_X_B88, XC_GGA_X_PW91, XC_GGA_C_LYP};
-  static FLOAT funcs_coef[4] = {1.0 - 0.722 - 0.347, 0.722, 0.347, 1.0};
+  static double funcs_coef[4] = {1.0 - 0.722 - 0.347, 0.722, 0.347, 1.0};
 
-  XC(mix_init)(p, 4, funcs_id, funcs_coef);
+  xc_mix_init(p, 4, funcs_id, funcs_coef);
 }
 
-const XC(func_info_type) XC(func_info_gga_xc_xlyp) = {
+const xc_func_info_type xc_func_info_gga_xc_xlyp = {
   XC_GGA_XC_XLYP,
   XC_EXCHANGE_CORRELATION,
   "XLYP",
   XC_FAMILY_GGA,
   {&xc_ref_Xu2004_2673, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-24,
+  0, NULL, NULL,
   gga_xc_xlyp_init, 
   NULL, NULL, NULL, NULL
 };
 
 
 static void
-gga_xc_pbe1w_init(XC(func_type) *p)
+gga_xc_pbe1w_init(xc_func_type *p)
 {
   static int   funcs_id  [3] = {XC_LDA_C_VWN, XC_GGA_X_PBE, XC_GGA_C_PBE};
-  static FLOAT funcs_coef[3] = {1.0 - 74.0/100.0, 1.0, 74.0/100.0};
+  static double funcs_coef[3] = {1.0 - 74.0/100.0, 1.0, 74.0/100.0};
 
-  XC(mix_init)(p, 3, funcs_id, funcs_coef);
+  xc_mix_init(p, 3, funcs_id, funcs_coef);
 }
 
-const XC(func_info_type) XC(func_info_gga_xc_pbe1w) = {
+const xc_func_info_type xc_func_info_gga_xc_pbe1w = {
   XC_GGA_XC_PBE1W,
   XC_EXCHANGE_CORRELATION,
   "PBE1W",
   XC_FAMILY_GGA,
   {&xc_ref_Dahlke2005_15677, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-24,
+  0, NULL, NULL,
   gga_xc_pbe1w_init, 
   NULL, NULL, NULL, NULL
 };
 
 
 static void
-gga_xc_mpwlyp1w_init(XC(func_type) *p)
+gga_xc_mpwlyp1w_init(xc_func_type *p)
 {
   static int   funcs_id  [3] = {XC_LDA_C_VWN, XC_GGA_X_MPW91, XC_GGA_C_LYP};
-  static FLOAT funcs_coef[3] = {1.0 - 88.0/100.0, 1.0, 88.0/100.0};
+  static double funcs_coef[3] = {1.0 - 88.0/100.0, 1.0, 88.0/100.0};
 
-  XC(mix_init)(p, 3, funcs_id, funcs_coef);
+  xc_mix_init(p, 3, funcs_id, funcs_coef);
 }
 
-const XC(func_info_type) XC(func_info_gga_xc_mpwlyp1w) = {
+const xc_func_info_type xc_func_info_gga_xc_mpwlyp1w = {
   XC_GGA_XC_MPWLYP1W,
   XC_EXCHANGE_CORRELATION,
   "mPWLYP1w",
   XC_FAMILY_GGA,
   {&xc_ref_Dahlke2005_15677, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-24,
+  0, NULL, NULL,
   gga_xc_mpwlyp1w_init, 
   NULL, NULL, NULL, NULL
 };
 
 
 static void
-gga_xc_pbelyp1w_init(XC(func_type) *p)
+gga_xc_pbelyp1w_init(xc_func_type *p)
 {
   static int   funcs_id  [3] = {XC_LDA_C_VWN, XC_GGA_X_PBE, XC_GGA_C_LYP};
-  static FLOAT funcs_coef[3] = {1.0 - 74.0/100.0, 1.0, 74.0/100.0};
+  static double funcs_coef[3] = {1.0 - 74.0/100.0, 1.0, 74.0/100.0};
 
-  XC(mix_init)(p, 3, funcs_id, funcs_coef);
+  xc_mix_init(p, 3, funcs_id, funcs_coef);
 }
 
-const XC(func_info_type) XC(func_info_gga_xc_pbelyp1w) = {
+const xc_func_info_type xc_func_info_gga_xc_pbelyp1w = {
   XC_GGA_XC_PBELYP1W,
   XC_EXCHANGE_CORRELATION,
   "PBELYP1W",
   XC_FAMILY_GGA,
   {&xc_ref_Dahlke2005_15677, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
+  1e-32,
+  0, NULL, NULL,
   gga_xc_pbelyp1w_init, 
   NULL, NULL, NULL, NULL
 };
