@@ -16,40 +16,30 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <assert.h>
 #include "util.h"
 
-#define XC_HYB_MGGA_X_MVSH     474 /* MVS hybrid */
+#define XC_HYB_MGGA_X_MVSH     474 /* MVSh hybrid */
 
 static void
-hyb_mgga_x_mvsh_init(XC(func_type) *p)
+hyb_mgga_x_mvsh_init(xc_func_type *p)
 {
   static int   funcs_id  [1] = {XC_MGGA_X_MVS};
-  static FLOAT funcs_coef[1] = {0.75};
+  static double funcs_coef[1] = {0.75};
 
-  XC(mix_init)(p, 1, funcs_id, funcs_coef);
+  xc_mix_init(p, 1, funcs_id, funcs_coef);
   p->cam_alpha = 0.25;
 }
 
-void 
-XC(hyb_mgga_x_mvsh_set_params)(XC(func_type) *p, FLOAT alpha)
-{
-  assert(alpha>=0 && alpha<=1.0);
 
-  p->cam_alpha   = alpha;
-  p->mix_coef[0] = 1.0 - alpha;
-}
-
-const XC(func_info_type) XC(func_info_hyb_mgga_x_mvsh) = {
+const xc_func_info_type xc_func_info_hyb_mgga_x_mvsh = {
   XC_HYB_MGGA_X_MVSH,
   XC_EXCHANGE,
   "MVSh hybrid exchange functional",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Sun2015_685, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  1e-32,
+  0, NULL, NULL,
   hyb_mgga_x_mvsh_init,
-  NULL, NULL, NULL, NULL /* this is taken care by the generic routine */
+  NULL, NULL, NULL, NULL /* this is taken care of by the generic routine */
 };
