@@ -16,73 +16,56 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <assert.h>
 #include "util.h"
 
 #define XC_HYB_MGGA_XC_TPSSH       457 /*    TPSS hybrid */
 #define XC_HYB_MGGA_XC_REVTPSSH    458 /* revTPSS hybrid */
 
 static void
-hyb_mgga_xc_tpssh_init(XC(func_type) *p)
+hyb_mgga_xc_tpssh_init(xc_func_type *p)
 {
   static int   funcs_id  [2] = {XC_MGGA_X_TPSS, XC_MGGA_C_TPSS};
-  static FLOAT funcs_coef[2] = {0.9, 1.0};
+  static double funcs_coef[2] = {0.9, 1.0};
 
-  XC(mix_init)(p, 2, funcs_id, funcs_coef);
+  xc_mix_init(p, 2, funcs_id, funcs_coef);
   p->cam_alpha = 0.10;
 }
 
-void 
-XC(hyb_mgga_xc_tpssh_set_params)(XC(func_type) *p, FLOAT alpha)
-{
-  assert(alpha>=0 && alpha<=1.0);
 
-  p->cam_alpha   = alpha;
-  p->mix_coef[0] = 1.0 - alpha;
-}
-
-const XC(func_info_type) XC(func_info_hyb_mgga_xc_tpssh) = {
+const xc_func_info_type xc_func_info_hyb_mgga_xc_tpssh = {
   XC_HYB_MGGA_XC_TPSSH,
   XC_EXCHANGE_CORRELATION,
   "TPSSh",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Staroverov2003_12129, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  1e-32,
+  0, NULL, NULL,
   hyb_mgga_xc_tpssh_init,
-  NULL, NULL, NULL, NULL /* this is taken care by the generic routine */
+  NULL, NULL, NULL, NULL /* this is taken care of by the generic routine */
 };
 
 
 static void
-hyb_mgga_xc_revtpssh_init(XC(func_type) *p)
+hyb_mgga_xc_revtpssh_init(xc_func_type *p)
 {
   static int   funcs_id  [2] = {XC_MGGA_X_REVTPSS, XC_MGGA_C_REVTPSS};
-  static FLOAT funcs_coef[2] = {0.9, 1.0};
+  static double funcs_coef[2] = {0.9, 1.0};
 
-  XC(mix_init)(p, 2, funcs_id, funcs_coef);
+  xc_mix_init(p, 2, funcs_id, funcs_coef);
   p->cam_alpha = 0.10;
 }
 
-void 
-XC(hyb_mgga_xc_revtpssh_set_params)(XC(func_type) *p, FLOAT alpha)
-{
-  assert(alpha>=0 && alpha<=1.0);
 
-  p->cam_alpha   = alpha;
-  p->mix_coef[0] = 1.0 - alpha;
-}
-
-const XC(func_info_type) XC(func_info_hyb_mgga_xc_revtpssh) = {
+const xc_func_info_type xc_func_info_hyb_mgga_xc_revtpssh = {
   XC_HYB_MGGA_XC_REVTPSSH,
   XC_EXCHANGE_CORRELATION,
   "revTPSSh",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Csonka2010_3688, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  1e-32,
+  0, NULL, NULL,
   hyb_mgga_xc_revtpssh_init,
-  NULL, NULL, NULL, NULL /* this is taken care by the generic routine */
+  NULL, NULL, NULL, NULL /* this is taken care of by the generic routine */
 };
