@@ -25,8 +25,6 @@
   R : A Computer Language for Statistical Data Analysis
 */
 
-#include <stdlib.h>
-#include <math.h>
 #include <float.h>
 #include <util.h>
 
@@ -34,27 +32,22 @@
 #define FALSE 0
 #define TRUE 1
 
-FLOAT XC(integrate)(integr_fn func, void *ex, FLOAT a, FLOAT b)
+double xc_integrate(integr_fn func, void *ex, double a, double b)
 {
-  FLOAT epsabs, epsrel, result, abserr, *alist, *blist, *rlist, *elist;
+  double epsabs, epsrel, result, abserr, *alist, *blist, *rlist, *elist;
   int limit, neval, ierr, *iord, last;
 
-#ifdef SINGLE_PRECISION
-  epsabs = 1e-5;
-  epsrel = 1e-5;
-#else
   epsabs = 1e-10;
   epsrel = 1e-10;
-#endif
 
   limit  = 1000;
-  alist = (FLOAT *)malloc(limit*sizeof(FLOAT));
-  blist = (FLOAT *)malloc(limit*sizeof(FLOAT));
-  rlist = (FLOAT *)malloc(limit*sizeof(FLOAT));
-  elist = (FLOAT *)malloc(limit*sizeof(FLOAT));
+  alist = (double *)malloc(limit*sizeof(double));
+  blist = (double *)malloc(limit*sizeof(double));
+  rlist = (double *)malloc(limit*sizeof(double));
+  elist = (double *)malloc(limit*sizeof(double));
   iord  = (int   *)malloc(limit*sizeof(int));
 
-  XC(rdqagse)(func, ex, &a, &b, &epsabs, &epsrel, &limit, &result, &abserr, &neval, &ierr,
+  xc_rdqagse(func, ex, &a, &b, &epsabs, &epsrel, &limit, &result, &abserr, &neval, &ierr,
 	    alist, blist, rlist, elist, iord, &last);
 
   free(alist);
@@ -69,16 +62,16 @@ FLOAT XC(integrate)(integr_fn func, void *ex, FLOAT a, FLOAT b)
 /* f2c-ed translations + modifications of QUADPACK functions from here down */
 
 static void rdqk21(integr_fn f, void *ex,
-		   FLOAT *, FLOAT *, FLOAT *, FLOAT *, FLOAT *, FLOAT *);
+		   double *, double *, double *, double *, double *, double *);
 
-static void rdqpsrt(int *, int *, int *, FLOAT *, FLOAT *, int *, int *);
+static void rdqpsrt(int *, int *, int *, double *, double *, int *, int *);
 
-static void rdqelg(int *, FLOAT *, FLOAT *, FLOAT *, FLOAT *, int *);
+static void rdqelg(int *, double *, double *, double *, double *, int *);
 
-void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b, 
-	     FLOAT *epsabs, FLOAT *epsrel, int *limit, FLOAT *result,
-	     FLOAT *abserr, int *neval, int *ier, FLOAT *alist__,
-	     FLOAT *blist, FLOAT *rlist, FLOAT *elist, int *iord, int *last)
+void xc_rdqagse(integr_fn f, void *ex, double *a, double *b, 
+	     double *epsabs, double *epsrel, int *limit, double *result,
+	     double *abserr, int *neval, int *ier, double *alist__,
+	     double *blist, double *rlist, double *elist, int *iord, int *last)
 {
   /* Local variables */
   int noext, extrap;
@@ -90,13 +83,13 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
   int numrl2;
   int jupbnd;
   int maxerr;
-  FLOAT res3la[3];
-  FLOAT rlist2[52];
-  FLOAT abseps, area, area1, area2, area12, dres, epmach;
-  FLOAT a1, a2, b1, b2, defabs, defab1, defab2, oflow, uflow, resabs, reseps;
-  FLOAT error1, error2, erro12, errbnd, erlast, errmax, errsum;
+  double res3la[3];
+  double rlist2[52];
+  double abseps, area, area1, area2, area12, dres, epmach;
+  double a1, a2, b1, b2, defabs, defab1, defab2, oflow, uflow, resabs, reseps;
+  double error1, error2, erro12, errbnd, erlast, errmax, errsum;
   
-  FLOAT correc = 0.0, erlarg = 0.0, ertest = 0.0, small = 0.0;
+  double correc = 0.0, erlarg = 0.0, ertest = 0.0, small = 0.0;
   /*
  ***begin prologue  dqagse
  ***date written   800101   (yymmdd)
@@ -115,24 +108,24 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
 
        computation of a definite integral
        standard fortran subroutine
-       FLOAT precision version
+       double precision version
 
        parameters
         on entry
-           f      - FLOAT precision
+           f      - double precision
                     function subprogram defining the integrand
                     function f(x). the actual name for f needs to be
                     declared e x t e r n a l in the driver program.
 
-           a      - FLOAT precision
+           a      - double precision
                     lower limit of integration
 
-           b      - FLOAT precision
+           b      - double precision
                     upper limit of integration
 
-           epsabs - FLOAT precision
+           epsabs - double precision
                     absolute accuracy requested
-           epsrel - FLOAT precision
+           epsrel - double precision
                     relative accuracy requested
                     if  epsabs <= 0
                     and epsrel < max(50*rel.mach.acc.,0.5d-28),
@@ -143,10 +136,10 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
                     in the partition of (a,b)
 
         on return
-           result - FLOAT precision
+           result - double precision
                     approximation to the integral
 
-           abserr - FLOAT precision
+           abserr - double precision
                     estimate of the modulus of the absolute error,
                     which should equal or exceed abs(i-result)
 
@@ -205,24 +198,24 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
                             alist(1) and blist(1) are set to a and b
                             respectively.
 
-           alist  - FLOAT precision
+           alist  - double precision
                     vector of dimension at least limit, the first
                      last  elements of which are the left end points
                     of the subintervals in the partition of the
                     given integration range (a,b)
 
-           blist  - FLOAT precision
+           blist  - double precision
                     vector of dimension at least limit, the first
                      last  elements of which are the right end points
                     of the subintervals in the partition of the given
                     integration range (a,b)
 
-           rlist  - FLOAT precision
+           rlist  - double precision
                     vector of dimension at least limit, the first
                      last  elements of which are the integral
                     approximations on the subintervals
 
-           elist  - FLOAT precision
+           elist  - double precision
                     vector of dimension at least limit, the first
                      last  elements of which are the moduli of the
                     absolute error estimates on the subintervals
@@ -308,7 +301,7 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
   --alist__;
 
   /* Function Body */
-  epmach = FLOAT_EPSILON;
+  epmach = DBL_EPSILON;
 
   /*            test on validity of parameters */
   /*            ------------------------------ */
@@ -329,14 +322,14 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
   /*           first approximation to the integral */
   /*           ----------------------------------- */
   
-  uflow = FLOAT_MIN;
-  oflow = FLOAT_MAX;
+  uflow = DBL_MIN;
+  oflow = DBL_MAX;
   ierro = 0;
   rdqk21(f, ex, a, b, result, abserr, &defabs, &resabs);
   
   /*           test on accuracy. */
   
-  dres = ABS(*result);
+  dres = fabs(*result);
   errbnd = max(*epsabs, *epsrel * dres);
   *last = 1;
   rlist[1] = *result;
@@ -397,7 +390,7 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
     if (defab1 == error1 || defab2 == error2) {
       goto L15;
     }
-    if (ABS(rlist[maxerr] - area12) > ABS(area12) * 1e-5 ||
+    if (fabs(rlist[maxerr] - area12) > fabs(area12) * 1e-5 ||
 	erro12 < errmax * .99) {
       goto L10;
     }
@@ -414,7 +407,7 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
   L15:
     rlist[maxerr] = area1;
     rlist[*last] = area2;
-    errbnd = max(*epsabs, *epsrel * ABS(area));
+    errbnd = max(*epsabs, *epsrel * fabs(area));
     
     /*           test for roundoff error and eventually set error flag. */
     
@@ -430,8 +423,8 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
     /*           set error flag in the case of bad integrand behaviour
 		 at a point of the integration range. */
     
-    if (max(ABS(a1), ABS(b2)) <=
-	(epmach * 100. + 1.) * (ABS(a2) + uflow * 1e3)) {
+    if (max(fabs(a1), fabs(b2)) <=
+	(epmach * 100. + 1.) * (fabs(a2) + uflow * 1e3)) {
       *ier = 4;
     }
     
@@ -467,7 +460,7 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
     if (noext)		    goto L90;
     
     erlarg -= erlast;
-    if (ABS(b1 - a1) > small) {
+    if (fabs(b1 - a1) > small) {
       erlarg += erro12;
     }
     if (extrap) {
@@ -477,7 +470,7 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
     /*           test whether the interval to be bisected next is the
 		 smallest interval. */
     
-    if (ABS(blist[maxerr] - alist__[maxerr]) > small) {
+    if (fabs(blist[maxerr] - alist__[maxerr]) > small) {
       goto L90;
     }
     extrap = TRUE;
@@ -499,7 +492,7 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
     for (k = id; k <= jupbnd; ++k) {
       maxerr = iord[nrmax];
       errmax = elist[maxerr];
-      if (ABS(blist[maxerr] - alist__[maxerr]) > small) {
+      if (fabs(blist[maxerr] - alist__[maxerr]) > small) {
 	goto L90;/* ***jump out of do-loop */
       }
       ++nrmax;
@@ -523,7 +516,7 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
     *abserr = abseps;
     *result = reseps;
     correc = erlarg;
-    ertest = max(*epsabs, *epsrel * ABS(reseps));
+    ertest = max(*epsabs, *epsrel * fabs(reseps));
     if (*abserr <= ertest) {
       goto L100;/* ***jump out of do-loop */
     }
@@ -545,7 +538,7 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
     erlarg = errsum;
     goto L90;
   L80:
-    small = ABS(*b - *a) * .375;
+    small = fabs(*b - *a) * .375;
     erlarg = errsum;
     ertest = errbnd;
     rlist2[1] = area;
@@ -568,15 +561,15 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
   goto L110;
   
  L105:
-  if (*abserr / ABS(*result) > errsum / ABS(area)) {
+  if (*abserr / fabs(*result) > errsum / fabs(area)) {
     goto L115;
   }
   
  L110:/*		test on divergence. */
-  if (ksgn == -1 && max(ABS(*result), ABS(area)) <= defabs * .01) {
+  if (ksgn == -1 && max(fabs(*result), fabs(area)) <= defabs * .01) {
     goto L130;
   }
-  if (.01 > *result / area || *result / area > 100. || errsum > ABS(area)) {
+  if (.01 > *result / area || *result / area > 100. || errsum > fabs(area)) {
     *ier = 5;
   }
   goto L130;
@@ -595,14 +588,14 @@ void XC(rdqagse)(integr_fn f, void *ex, FLOAT *a, FLOAT *b,
 } /* rdqagse_ */
 
 
-static void rdqelg(int *n, FLOAT *epstab, FLOAT *
-		   result, FLOAT *abserr, FLOAT *res3la, int *nres)
+static void rdqelg(int *n, double *epstab, double *
+		   result, double *abserr, double *res3la, int *nres)
 {
   /* Local variables */
   int i__, indx, ib, ib2, ie, k1, k2, k3, num, newelm, limexp;
-  FLOAT delta1, delta2, delta3, e0, e1, e1abs, e2, e3, epmach, epsinf;
-  FLOAT oflow, ss, res;
-  FLOAT errA, err1, err2, err3, tol1, tol2, tol3;
+  double delta1, delta2, delta3, e0, e1, e1abs, e2, e3, epmach, epsinf;
+  double oflow, ss, res;
+  double errA, err1, err2, err3, tol1, tol2, tol3;
   
   /* ***begin prologue  dqelg
  ***refer to  dqagie,dqagoe,dqagpe,dqagse
@@ -621,28 +614,28 @@ static void rdqelg(int *n, FLOAT *epstab, FLOAT *
 
           epsilon algorithm
           standard fortran subroutine
-          FLOAT precision version
+          double precision version
 
           parameters
              n      - int
                       epstab(n) contains the new element in the
                       first column of the epsilon table.
 
-             epstab - FLOAT precision
+             epstab - double precision
                       vector of dimension 52 containing the elements
                       of the two lower diagonals of the triangular
                       epsilon table. the elements are numbered
                       starting at the right-hand corner of the
                       triangle.
 
-             result - FLOAT precision
+             result - double precision
                       resulting approximation to the integral
 
-             abserr - FLOAT precision
+             abserr - double precision
                       estimate of the absolute error computed from
                       result and the 3 previous results
 
-             res3la - FLOAT precision
+             res3la - double precision
                       vector of dimension 3 containing the last 3
                       results
 
@@ -682,8 +675,8 @@ static void rdqelg(int *n, FLOAT *epstab, FLOAT *
   --epstab;
 
   /* Function Body */
-  epmach = FLOAT_EPSILON;
-  oflow = FLOAT_MAX;
+  epmach = DBL_EPSILON;
+  oflow = DBL_MAX;
   ++(*nres);
   *abserr = oflow;
   *result = epstab[*n];
@@ -703,18 +696,18 @@ static void rdqelg(int *n, FLOAT *epstab, FLOAT *
     e0 = epstab[k3];
     e1 = epstab[k2];
     e2 = res;
-    e1abs = ABS(e1);
+    e1abs = fabs(e1);
     delta2 = e2 - e1;
-    err2 = ABS(delta2);
-    tol2 = max(ABS(e2), e1abs) * epmach;
+    err2 = fabs(delta2);
+    tol2 = max(fabs(e2), e1abs) * epmach;
     delta3 = e1 - e0;
-    err3 = ABS(delta3);
-    tol3 = max(e1abs, ABS(e0)) * epmach;
+    err3 = fabs(delta3);
+    tol3 = max(e1abs, fabs(e0)) * epmach;
     if (err2 <= tol2 && err3 <= tol3) {
       /*           if e0, e1 and e2 are equal to within machine
 		   accuracy, convergence is assumed. */
       *result = res;/*		result = e2 */
-      *abserr = err2 + err3;/*	abserr = ABS(e1-e0)+ABS(e2-e1) */
+      *abserr = err2 + err3;/*	abserr = fabs(e1-e0)+fabs(e2-e1) */
       
       goto L100;	/* ***jump out of do-loop */
     }
@@ -722,15 +715,15 @@ static void rdqelg(int *n, FLOAT *epstab, FLOAT *
     e3 = epstab[k1];
     epstab[k1] = e1;
     delta1 = e1 - e3;
-    err1 = ABS(delta1);
-    tol1 = max(e1abs, ABS(e3)) * epmach;
+    err1 = fabs(delta1);
+    tol1 = max(e1abs, fabs(e3)) * epmach;
     
     /*           if two elements are very close to each other, omit
 		 a part of the table by adjusting the value of n */
     
     if (err1 > tol1 && err2 > tol2 && err3 > tol3) {
       ss = 1. / delta1 + 1. / delta2 - 1. / delta3;
-      epsinf = ABS(ss * e1);
+      epsinf = fabs(ss * e1);
       
       /*           test to detect irregular behaviour in the table, and
 		   eventually omit a part of the table adjusting the value of n. */
@@ -749,7 +742,7 @@ static void rdqelg(int *n, FLOAT *epstab, FLOAT *
     res = e1 + 1. / ss;
     epstab[k1] = res;
     k1 += -2;
-    errA = err2 + ABS(res - e2) + err3;
+    errA = err2 + fabs(res - e2) + err3;
     if (errA <= *abserr) {
       *abserr = errA;
       *result = res;
@@ -780,9 +773,9 @@ static void rdqelg(int *n, FLOAT *epstab, FLOAT *
   /*L80:*/
   if (*nres >= 4) {
     /* L90: */
-    *abserr = ABS(*result - res3la[3]) +
-      ABS(*result - res3la[2]) +
-      ABS(*result - res3la[1]);
+    *abserr = fabs(*result - res3la[3]) +
+      fabs(*result - res3la[2]) +
+      fabs(*result - res3la[1]);
     res3la[1] = res3la[2];
     res3la[2] = res3la[3];
     res3la[3] = *result;
@@ -792,21 +785,21 @@ static void rdqelg(int *n, FLOAT *epstab, FLOAT *
   }
   
  L100:/* compute error estimate */
-  *abserr = max(*abserr, epmach * 5. * ABS(*result));
+  *abserr = max(*abserr, epmach * 5. * fabs(*result));
   return;
 } /* rdqelg_ */
 
-static void  rdqk21(integr_fn f, void *ex, FLOAT *a, FLOAT *b, FLOAT *result,
-		    FLOAT *abserr, FLOAT *resabs, FLOAT *resasc)
+static void  rdqk21(integr_fn f, void *ex, double *a, double *b, double *result,
+		    double *abserr, double *resabs, double *resasc)
 {
   /* Initialized data */
   
-  static FLOAT wg[5] = { .066671344308688137593568809893332,
+  static double wg[5] = { .066671344308688137593568809893332,
 			  .149451349150580593145776339657697,
 			  .219086362515982043995534934228163,
 			  .269266719309996355091226921569469,
 			  .295524224714752870173892994651338 };
-  static FLOAT xgk[11] = { .995657163025808080735527280689003,
+  static double xgk[11] = { .995657163025808080735527280689003,
 			    .973906528517171720077964012084452,
 			    .930157491355708226001207180059508,
 			    .865063366688984510732096688423493,
@@ -816,7 +809,7 @@ static void  rdqk21(integr_fn f, void *ex, FLOAT *a, FLOAT *b, FLOAT *result,
 			    .433395394129247190799265943165784,
 			    .294392862701460198131126603103866,
 			    .14887433898163121088482600112972,0. };
-  static FLOAT wgk[11] = { .011694638867371874278064396062192,
+  static double wgk[11] = { .011694638867371874278064396062192,
 			    .03255816230796472747881897245939,
 			    .05475589657435199603138130024458,
 			    .07503967481091995276704314091619,
@@ -830,10 +823,10 @@ static void  rdqk21(integr_fn f, void *ex, FLOAT *a, FLOAT *b, FLOAT *result,
 
 
   /* Local variables */
-  FLOAT fv1[10], fv2[10], vec[21];
-  FLOAT absc, resg, resk, fsum, fval1, fval2;
-  FLOAT hlgth, centr, reskh, uflow;
-  FLOAT fc, epmach, dhlgth;
+  double fv1[10], fv2[10], vec[21];
+  double absc, resg, resk, fsum, fval1, fval2;
+  double hlgth, centr, reskh, uflow;
+  double fc, epmach, dhlgth;
   int j, jtw, jtwm1;
   
 /* ***begin prologue  dqk21
@@ -850,36 +843,36 @@ static void  rdqk21(integr_fn f, void *ex, FLOAT *a, FLOAT *b, FLOAT *result,
 
           integration rules
           standard fortran subroutine
-          FLOAT precision version
+          double precision version
 
           parameters
            on entry
-             f      - FLOAT precision
+             f      - double precision
                       function subprogram defining the integrand
                       function f(x). the actual name for f needs to be
                       declared e x t e r n a l in the driver program.
 
-             a      - FLOAT precision
+             a      - double precision
                       lower limit of integration
 
-             b      - FLOAT precision
+             b      - double precision
                       upper limit of integration
 
            on return
-             result - FLOAT precision
+             result - double precision
                       approximation to the integral i
                       result is computed by applying the 21-point
                       kronrod rule (resk) obtained by optimal addition
                       of abscissae to the 10-point gauss rule (resg).
 
-             abserr - FLOAT precision
+             abserr - double precision
                       estimate of the modulus of the absolute error,
                       which should not exceed abs(i-result)
 
-             resabs - FLOAT precision
+             resabs - double precision
                       approximation to the integral j
 
-             resasc - FLOAT precision
+             resasc - double precision
                       approximation to the integral of abs(f-i/(b-a))
                       over (a,b)
 
@@ -931,12 +924,12 @@ bell labs, nov. 1981.
           uflow is the smallest positive magnitude. */
 
 /* ***first executable statement  dqk21 */
-  epmach = FLOAT_EPSILON;
-  uflow = FLOAT_MIN;
+  epmach = DBL_EPSILON;
+  uflow = DBL_MIN;
   
   centr = (*a + *b) * .5;
   hlgth = (*b - *a) * .5;
-  dhlgth = ABS(hlgth);
+  dhlgth = fabs(hlgth);
 
   /*           compute the 21-point kronrod approximation to
 	       the integral, and estimate the absolute error. */
@@ -959,7 +952,7 @@ bell labs, nov. 1981.
   f(vec, 21, ex);
   fc = vec[0];
   resk = wgk[10] * fc;
-  *resabs = ABS(resk);
+  *resabs = fabs(resk);
   for (j = 1; j <= 5; ++j) {
     jtw = j << 1;
     absc = hlgth * xgk[jtw - 1];
@@ -970,7 +963,7 @@ bell labs, nov. 1981.
     fsum = fval1 + fval2;
     resg += wg[j - 1] * fsum;
     resk += wgk[jtw - 1] * fsum;
-    *resabs += wgk[jtw - 1] * (ABS(fval1) + ABS(fval2));
+    *resabs += wgk[jtw - 1] * (fabs(fval1) + fabs(fval2));
     /* L10: */
   }
   for (j = 1; j <= 5; ++j) {
@@ -982,22 +975,22 @@ bell labs, nov. 1981.
     fv2[jtwm1 - 1] = fval2;
     fsum = fval1 + fval2;
     resk += wgk[jtwm1 - 1] * fsum;
-    *resabs += wgk[jtwm1 - 1] * (ABS(fval1) + ABS(fval2));
+    *resabs += wgk[jtwm1 - 1] * (fabs(fval1) + fabs(fval2));
     /* L15: */
   }
   reskh = resk * .5;
-  *resasc = wgk[10] * ABS(fc - reskh);
+  *resasc = wgk[10] * fabs(fc - reskh);
   for (j = 1; j <= 10; ++j) {
-    *resasc += wgk[j - 1] * (ABS(fv1[j - 1] - reskh) +
-			     ABS(fv2[j - 1] - reskh));
+    *resasc += wgk[j - 1] * (fabs(fv1[j - 1] - reskh) +
+			     fabs(fv2[j - 1] - reskh));
     /* L20: */
   }
   *result = resk * hlgth;
   *resabs *= dhlgth;
   *resasc *= dhlgth;
-  *abserr = ABS((resk - resg) * hlgth);
+  *abserr = fabs((resk - resg) * hlgth);
   if (*resasc != 0. && *abserr != 0.) {
-    *abserr = *resasc * min(1., POW(*abserr * 200. / *resasc, 1.5));
+    *abserr = *resasc * min(1., pow(*abserr * 200. / *resasc, 1.5));
   }
   if (*resabs > uflow / (epmach * 50.)) {
     *abserr = max(epmach * 50. * *resabs, *abserr);
@@ -1007,11 +1000,11 @@ bell labs, nov. 1981.
 
 
 static void rdqpsrt(int *limit, int *last, int *maxerr,
-		    FLOAT *ermax, FLOAT *elist, int *iord, int *nrmax)
+		    double *ermax, double *elist, int *iord, int *nrmax)
 {
   /* Local variables */
   int i, j, k, ido, jbnd, isucc, jupbn;
-  FLOAT errmin, errmax;
+  double errmin, errmax;
 
 /* ***begin prologue  dqpsrt
  ***refer to  dqage,dqagie,dqagpe,dqawse
@@ -1030,7 +1023,7 @@ static void rdqpsrt(int *limit, int *last, int *maxerr,
 
            ordering routine
            standard fortran subroutine
-           FLOAT precision version
+           double precision version
 
            parameters (meaning at output)
               limit  - int
@@ -1044,11 +1037,11 @@ static void rdqpsrt(int *limit, int *last, int *maxerr,
                        maxerr points to the nrmax-th largest error
                        estimate currently in the list
 
-              ermax  - FLOAT precision
+              ermax  - double precision
                        nrmax-th largest error estimate
                        ermax = elist(maxerr)
 
-              elist  - FLOAT precision
+              elist  - double precision
                        vector of dimension last containing
                        the error estimates
 
