@@ -16,43 +16,26 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <stdlib.h>
-#include <assert.h>
 #include "util.h"
 
 /* Local tau approximation */
 
 #define XC_MGGA_X_LTA          201 /* Local tau approximation of Ernzerhof & Scuseria */
 
-static void 
-func(const XC(func_type) *pt, XC(mgga_work_x_t) *r)
-{
-  /* POW(10.0/(3.0*POW(6.0*M_PI*M_PI, 2.0/3.0)), 4.0/5.0) = (2/C_F)^(4/5) */
-  const FLOAT a1 = 0.297163728291293581339216378935;
-  FLOAT t;
-
-  t  = r->t; /* we use a different definition of t */
-  r->f = a1*POW(t, 4.0/5.0);
-
-  if(r->order < 1) return;
-  
-  r->dfdt = (t > 1e-10) ? a1*4.0/5.0*POW(t, -1.0/5.0) : 0.0;
-
-  if(r->order < 2) return;
-  
-  r->d2fdt2 = (t > 1e-10) ? -a1*4.0/25.0*POW(t, -6.0/5.0) : 0.0;
-}
+#include "maple2c/mgga_x_lta.c"
 
+#define func maple2c_func
 #include "work_mgga_x.c"
 
-const XC(func_info_type) XC(func_info_mgga_x_lta) = {
+const xc_func_info_type xc_func_info_mgga_x_lta = {
   XC_MGGA_X_LTA,
   XC_EXCHANGE,
   "Local tau approximation",
   XC_FAMILY_MGGA,
   {&xc_ref_Ernzerhof1999_911, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
-  MIN_DENS, MIN_GRAD, MIN_TAU, MIN_ZETA,
+  1.0e-23,
+  0, NULL, NULL,
   NULL, NULL,
   NULL, NULL,        /* this is not an LDA                   */
   work_mgga_x,
