@@ -16,32 +16,30 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <assert.h>
 #include "util.h"
 
 #define XC_MGGA_XC_OTPSS_D      64  /* oTPSS_D functional of Goerigk and Grimme   */
 
 static void
-mgga_xc_otpss_d_init(XC(func_type) *p)
+mgga_xc_otpss_d_init(xc_func_type *p)
 {
   static int   funcs_id  [2] = {XC_MGGA_X_TPSS, XC_MGGA_C_TPSS};
-  static FLOAT funcs_coef[2] = {1.0, 1.0};
+  static double funcs_coef[2] = {1.0, 1.0};
 
-  XC(mix_init)(p, 2, funcs_id, funcs_coef);
-  XC(mgga_x_tpss_set_params)(p->func_aux[0], 3.43, 0.75896, 0.165, 0.778, 0.41567);
-  XC(mgga_c_pkzb_set_params)(p->func_aux[1], 0.08861, 0.7, 0.59, 0.9269, 0.6225, 2.1540);
+  xc_mix_init(p, 2, funcs_id, funcs_coef);
+  xc_mgga_x_tpss_set_params(p->func_aux[0], 3.43, 0.75896, 0.165, 0.778, 0.41567, 2.0, 0.0);
+  xc_mgga_c_tpss_set_params(p->func_aux[1], 0.08861, 0.7, 0.59, 0.9269, 0.6225, 2.1540);
 }
 
-const XC(func_info_type) XC(func_info_mgga_xc_otpss_d) = {
+const xc_func_info_type xc_func_info_mgga_xc_otpss_d = {
   XC_MGGA_XC_OTPSS_D,
   XC_EXCHANGE_CORRELATION,
   "oTPSS-D functional of Goerigk and Grimme",
   XC_FAMILY_MGGA,
   {&xc_ref_Goerigk2010_107, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC,
-  1e-32, 1e-32, 0.0, 1e-32,
+  1e-23,
+  0, NULL, NULL,
   mgga_xc_otpss_d_init,
   NULL, NULL, NULL, NULL
 };
