@@ -16,9 +16,6 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <assert.h>
 
 #include "util.h"
 
@@ -26,7 +23,7 @@
 /* this function converts the spin-density into total density and
 	 relative magnetization */
 /* inline */ void
-XC(rho2dzeta)(int nspin, const FLOAT *rho, FLOAT *d, FLOAT *zeta)
+xc_rho2dzeta(int nspin, const double *rho, double *d, double *zeta)
 {
   if(nspin==XC_UNPOLARIZED){
     *d    = max(rho[0], 0.0);
@@ -45,9 +42,9 @@ XC(rho2dzeta)(int nspin, const FLOAT *rho, FLOAT *d, FLOAT *zeta)
 }
 
 /* inline */ void
-XC(fast_fzeta)(const FLOAT x, const int nspin, const int order, FLOAT * fz){
+xc_fast_fzeta(const double x, const int nspin, const int order, double * fz){
 
-  FLOAT aa, bb, aa2, bb2;
+  double aa, bb, aa2, bb2;
 
   if(nspin != XC_UNPOLARIZED){
     aa = CBRT(1.0 + x);
@@ -60,9 +57,9 @@ XC(fast_fzeta)(const FLOAT x, const int nspin, const int order, FLOAT * fz){
     if(order < 1) return;
     fz[1] = (aa - bb)*(4.0/3.0)/FZETAFACTOR;
     if(order < 2) return;
-    fz[2] = ((4.0/9.0)/FZETAFACTOR)*(ABS(x)==1.0 ? (FLT_MAX) : (pow(1.0 + (x), -2.0/3.0) + pow(1.0 - (x), -2.0/3.0)));
+    fz[2] = ((4.0/9.0)/FZETAFACTOR)*(fabs(x)==1.0 ? (FLT_MAX) : (pow(1.0 + (x), -2.0/3.0) + pow(1.0 - (x), -2.0/3.0)));
     if(order < 3) return;
-    fz[3] = (-(8.0/27.0)/FZETAFACTOR)*(ABS(x)==1.0 ? (FLT_MAX) : (pow(1.0 + (x), -5.0/3.0) - pow(1.0 - (x), -5.0/3.0)));
+    fz[3] = (-(8.0/27.0)/FZETAFACTOR)*(fabs(x)==1.0 ? (FLT_MAX) : (pow(1.0 + (x), -5.0/3.0) - pow(1.0 - (x), -5.0/3.0)));
   } else {
     fz[0] = 0.0;
     fz[1] = 0.0;
@@ -73,7 +70,7 @@ XC(fast_fzeta)(const FLOAT x, const int nspin, const int order, FLOAT * fz){
 
 /* initializes the mixing */
 void 
-XC(mix_init)(XC(func_type) *p, int n_funcs, const int *funcs_id, const FLOAT *mix_coef)
+xc_mix_init(xc_func_type *p, int n_funcs, const int *funcs_id, const double *mix_coef)
 {
   int ii;
 
@@ -82,13 +79,13 @@ XC(mix_init)(XC(func_type) *p, int n_funcs, const int *funcs_id, const FLOAT *mi
 
   /* allocate structures needed for */
   p->n_func_aux = n_funcs;
-  p->mix_coef   = (FLOAT *) malloc(n_funcs*sizeof(FLOAT));
-  p->func_aux   = (XC(func_type) **) malloc(n_funcs*sizeof(XC(func_type) *));
+  p->mix_coef   = (double *) malloc(n_funcs*sizeof(double));
+  p->func_aux   = (xc_func_type **) malloc(n_funcs*sizeof(xc_func_type *));
 
   for(ii=0; ii<n_funcs; ii++){
     p->mix_coef[ii] = mix_coef[ii];
-    p->func_aux[ii] = (XC(func_type) *) malloc(sizeof(XC(func_type)));
-    XC(func_init) (p->func_aux[ii], funcs_id[ii], p->nspin);
+    p->func_aux[ii] = (xc_func_type *) malloc(sizeof(xc_func_type));
+    xc_func_init (p->func_aux[ii], funcs_id[ii], p->nspin);
   }
 
   /* initialize variables */
@@ -100,12 +97,12 @@ XC(mix_init)(XC(func_type) *p, int n_funcs, const int *funcs_id, const FLOAT *mi
 }
 
 xc_gga_enhancement_t
-XC(get_gga_enhancement_factor)(int func_id)
+xc_get_gga_enhancement_factor(int func_id)
 {
   switch(func_id){
 
   case XC_GGA_X_WC:
-    return XC(gga_x_wc_enhance);
+    return xc_gga_x_wc_enhance;
 
   case XC_GGA_X_PBE:
   case XC_GGA_X_PBE_R:
@@ -117,87 +114,140 @@ XC(get_gga_enhancement_factor)(int func_id)
   case XC_GGA_X_APBE:
   case XC_GGA_X_PBEINT:
   case XC_GGA_X_PBE_TCA:
-    return XC(gga_x_pbe_enhance);
+    return xc_gga_x_pbe_enhance;
 
   case XC_GGA_X_PW91:
   case XC_GGA_X_MPW91:
-    return XC(gga_x_pw91_enhance);
+    return xc_gga_x_pw91_enhance;
 
   case XC_GGA_X_RPBE:
-    return XC(gga_x_rpbe_enhance);
+    return xc_gga_x_rpbe_enhance;
 
   case XC_GGA_X_HTBS:
-    return XC(gga_x_htbs_enhance);
+    return xc_gga_x_htbs_enhance;
 
   case XC_GGA_X_B86:
   case XC_GGA_X_B86_MGC:
   case XC_GGA_X_B86_R:
-    return XC(gga_x_b86_enhance);
+    return xc_gga_x_b86_enhance;
 
   case XC_GGA_X_B88:
   case XC_GGA_X_OPTB88_VDW:
   case XC_GGA_X_MB88:
-    return XC(gga_x_b88_enhance);
+    return xc_gga_x_b88_enhance;
 
   case XC_GGA_X_G96:
-    return XC(gga_x_g96_enhance);
+    return xc_gga_x_g96_enhance;
 
   case XC_GGA_X_PW86:
   case XC_GGA_X_RPW86:
-    return XC(gga_x_pw86_enhance);
+    return xc_gga_x_pw86_enhance;
 
   case XC_GGA_X_AIRY:
   case XC_GGA_X_LAG:
-    return XC(gga_x_airy_enhance);
+    return xc_gga_x_airy_enhance;
 
   case XC_GGA_X_BAYESIAN:
-    return XC(gga_x_bayesian_enhance);
+    return xc_gga_x_bayesian_enhance;
 
   case XC_GGA_X_BPCCAC:
-    return XC(gga_x_bpccac_enhance);
+    return xc_gga_x_bpccac_enhance;
 
   case XC_GGA_X_C09X:
-    return XC(gga_x_c09x_enhance);
+    return xc_gga_x_c09x_enhance;
 
   case XC_GGA_X_AM05:
-    return XC(gga_x_am05_enhance);
+    return xc_gga_x_am05_enhance;
 
   case XC_GGA_X_DK87_R1:
   case XC_GGA_X_DK87_R2:
-    return XC(gga_x_dk87_enhance);
+    return xc_gga_x_dk87_enhance;
 
   case XC_GGA_X_HERMAN:
-    return XC(gga_x_herman_enhance);
+    return xc_gga_x_herman_enhance;
 
   case XC_GGA_X_LG93:
-    return XC(gga_x_lg93_enhance);
+    return xc_gga_x_lg93_enhance;
 
   case XC_GGA_X_LV_RPW86:
-    return XC(gga_x_lv_rpw86_enhance);
+    return xc_gga_x_lv_rpw86_enhance;
 
   case XC_GGA_X_MPBE:
-    return XC(gga_x_mpbe_enhance);
+    return xc_gga_x_mpbe_enhance;
 
   case XC_GGA_X_OPTX:
-    return XC(gga_x_optx_enhance);
+    return xc_gga_x_optx_enhance;
 
   case XC_GGA_X_SOGGA11:
   case XC_HYB_GGA_X_SOGGA11_X:
-    return XC(gga_x_sogga11_enhance);
+    return xc_gga_x_sogga11_enhance;
 
   case XC_GGA_X_SSB_SW:
   case XC_GGA_X_SSB:
   case XC_GGA_X_SSB_D:
-    return XC(gga_x_ssb_sw_enhance);
+    return xc_gga_x_ssb_sw_enhance;
 
   case XC_GGA_X_VMT_PBE:
   case XC_GGA_X_VMT_GE:
   case XC_GGA_X_VMT84_PBE:
   case XC_GGA_X_VMT84_GE:
-    return XC(gga_x_vmt_enhance);
+    return xc_gga_x_vmt_enhance;
 
   default:
     fprintf(stderr, "Internal error in get_gga_enhancement\n");
     exit(1);
   }
 }
+
+
+const char *get_kind(const xc_func_type *func) {
+  switch(func->info->kind) {
+    case(XC_EXCHANGE):
+      return "XC_EXCHANGE";
+
+    case(XC_CORRELATION):
+      return "XC_CORRELATION";
+
+    case(XC_EXCHANGE_CORRELATION):
+      return "XC_EXCHANGE_CORRELATION";
+
+    case(XC_KINETIC):
+      return "XC_KINETIC";
+
+    default:
+      printf("Internal error in get_kind.\n");
+      return "";
+  }
+}
+
+const char *get_family(const xc_func_type *func) {
+  switch(func->info->family) {
+    case(XC_FAMILY_UNKNOWN):
+      return "XC_FAMILY_UNKNOWN";
+
+    case(XC_FAMILY_LDA):
+      return "XC_FAMILY_LDA";
+
+    case(XC_FAMILY_GGA):
+      return "XC_FAMILY_GGA";
+
+    case(XC_FAMILY_MGGA):
+      return "XC_FAMILY_MGGA";
+
+    case(XC_FAMILY_LCA):
+      return "XC_FAMILY_LCA";
+
+    case(XC_FAMILY_OEP):
+      return "XC_FAMILY_OEP";
+
+    case(XC_FAMILY_HYB_GGA):
+      return "XC_FAMILY_HYB_GGA";
+
+    case(XC_FAMILY_HYB_MGGA):
+      return "XC_FAMILY_HYB_MGGA";
+
+    default:
+      printf("Internal error in get_family.\n");
+      return "";
+  }
+}
