@@ -16,17 +16,16 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <string.h>
 
 static void 
-work_mgga_c(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma, const FLOAT *lapl, const FLOAT *tau,
-	    FLOAT *zk, FLOAT *vrho, FLOAT *vsigma, FLOAT *vlapl, FLOAT *vtau,
-	    FLOAT *v2rho2, FLOAT *v2sigma2, FLOAT *v2lapl2, FLOAT *v2tau2,
-	    FLOAT *v2rhosigma, FLOAT *v2rholapl, FLOAT *v2rhotau, 
-	    FLOAT *v2sigmalapl, FLOAT *v2sigmatau, FLOAT *v2lapltau)
+work_mgga_c(const xc_func_type *p, int np, const double *rho, const double *sigma, const double *lapl, const double *tau,
+	    double *zk, double *vrho, double *vsigma, double *vlapl, double *vtau,
+	    double *v2rho2, double *v2sigma2, double *v2lapl2, double *v2tau2,
+	    double *v2rhosigma, double *v2rholapl, double *v2rhotau, 
+	    double *v2sigmalapl, double *v2sigmatau, double *v2lapltau)
 {
-  XC(mgga_work_c_t) r;
-  FLOAT min_grad2 = p->info->min_grad*p->info->min_grad;
+  xc_mgga_work_c_t r;
+  double min_grad2 = p->dens_threshold*p->dens_threshold, min_tau = p->dens_threshold;
   int ip;
 
   /* set all elements of r to zero */
@@ -40,15 +39,15 @@ work_mgga_c(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma
   if(r.order < 0) return;
 
   for(ip = 0; ip < np; ip++){
-    FLOAT rho13[3], drs, dxt;
-    FLOAT ndzdn[2], dxsdn[2];
-    FLOAT dxtds, dxsds[2];
-    FLOAT dusdn[2], dusdlapl[2], dtsdn[2], dtsdtau[2];
+    double rho13[3], drs, dxt;
+    double ndzdn[2], dxsdn[2];
+    double dxtds, dxsds[2];
+    double dusdn[2], dusdlapl[2], dtsdn[2], dtsdtau[2];
 
-    XC(rho2dzeta)(p->nspin, rho, &(r.dens), &(r.zeta));
-
-    if(r.dens < p->info->min_dens) goto end_ip_loop;
+    xc_rho2dzeta(p->nspin, rho, &(r.dens), &(r.z));
 
+    if(r.dens < p->dens_threshold) goto end_ip_loop;
+    
     r.rs = RS(r.dens);
     rho13[2] = CBRT(r.dens);
 
@@ -61,7 +60,7 @@ work_mgga_c(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma
 
       /* we already know that dens > min_dens */
       r.sigmat = max(min_grad2, sigma[0]);
-      r.xt     = SQRT(r.sigmat)/(r.dens*rho13[2]);
+      r.xt     = sqrt(r.sigmat)/(r.dens*rho13[2]);
 
       r.sigmas[0] = r.sigmat/4.0;
       r.sigmas[1] = r.sigmas[0];
@@ -70,33 +69,43 @@ work_mgga_c(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma
       r.xs[0]  = M_CBRT2*r.xt;
       r.xs[1]  = r.xs[0];
 
-      r.us[0]  = lapl[0]/(2.0*r.ds[0]*rho13[0]*rho13[0]); /* lapl/rho^(5/3) */
-      r.us[1]  = r.us[0];
+      if(p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN){
+        r.us[0]  = lapl[0]/(2.0*r.ds[0]*rho13[0]*rho13[0]); /* lapl/rho^(5/3) */
+        r.us[1]  = r.us[0];
+      }
 
-      r.ts[0]  = tau[0]/(2.0*r.ds[0]*rho13[0]*rho13[0]);  /* tau/rho^(5/3) */
+      r.ts[0]  = max(2.0*min_tau, tau[0]/(2.0*r.ds[0]*rho13[0]*rho13[0]));  /* tau/rho^(5/3) */
       r.ts[1]  = r.ts[0];
     }else{
-      r.ds[0]  = max(p->info->min_dens, rho[0]);
-      r.ds[1]  = max(p->info->min_dens, rho[1]);
+      /* there are lots of derivatives that involve inverse
+         powers of (1 +- z). For these not to give NaN, we
+         must have abs(1 +- z) > DBL_EPSILON                 */
+      if(1.0 + r.z < DBL_EPSILON) r.z = -1.0 + DBL_EPSILON;
+      if(1.0 - r.z < DBL_EPSILON) r.z =  1.0 - DBL_EPSILON;
+
+      r.ds[0]  = max(p->dens_threshold, rho[0]);
+      r.ds[1]  = max(p->dens_threshold, rho[1]);
 
       rho13[0] = CBRT(r.ds[0]);
       rho13[1] = CBRT(r.ds[1]);
       
       r.sigmat = max(min_grad2, sigma[0] + 2.0*sigma[1] + sigma[2]);
-      r.xt     = SQRT(r.sigmat)/(r.dens*rho13[2]);
+      r.xt     = sqrt(r.sigmat)/(r.dens*rho13[2]);
       
       r.sigmas[0] = max(min_grad2, sigma[0]);
       r.sigmas[1] = max(min_grad2, sigma[1]);
       r.sigmas[2] = max(min_grad2, sigma[2]);
 
-      r.xs[0] = SQRT(r.sigmas[0])/(r.ds[0]*rho13[0]);
-      r.xs[1] = SQRT(r.sigmas[2])/(r.ds[1]*rho13[1]);
+      r.xs[0] = sqrt(r.sigmas[0])/(r.ds[0]*rho13[0]);
+      r.xs[1] = sqrt(r.sigmas[2])/(r.ds[1]*rho13[1]);
 
-      r.us[0]   = lapl[0]/(r.ds[0]*rho13[0]*rho13[0]);
-      r.us[1]   = lapl[1]/(r.ds[1]*rho13[1]*rho13[1]);
+      if(p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN){
+        r.us[0]   = lapl[0]/(r.ds[0]*rho13[0]*rho13[0]);
+        r.us[1]   = lapl[1]/(r.ds[1]*rho13[1]*rho13[1]);
+      }
 
-      r.ts[0]   = tau[0]/(r.ds[0]*rho13[0]*rho13[0]);
-      r.ts[1]   = tau[1]/(r.ds[1]*rho13[1]*rho13[1]);
+      r.ts[0]   = max(min_tau, tau[0]/(r.ds[0]*rho13[0]*rho13[0]));
+      r.ts[1]   = max(min_tau, tau[1]/(r.ds[1]*rho13[1]*rho13[1]));
     }
   
     func(p, &r);
@@ -112,8 +121,8 @@ work_mgga_c(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma
     dxtds = r.xt/(2.0*r.sigmat);
 
     if(p->nspin == XC_POLARIZED){
-      ndzdn[1]    = -(r.zeta + 1.0);
-      ndzdn[0]    = -(r.zeta - 1.0);
+      ndzdn[1]    = -(r.z + 1.0);
+      ndzdn[0]    = -(r.z - 1.0);
 
       dxsdn[1]    = -4.0*r.xs[1]/(3.0*r.ds[1]);
       dxsdn[0]    = -4.0*r.xs[0]/(3.0*r.ds[0]);
@@ -121,26 +130,31 @@ work_mgga_c(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma
       dxsds[1]    = r.xs[1]/(2.0*r.sigmas[2]);
       dxsds[0]    = r.xs[0]/(2.0*r.sigmas[0]);
 
-      dusdn[1]    = -5.0*r.us[1]/(3.0*r.ds[1]);
-      dusdn[0]    = -5.0*r.us[0]/(3.0*r.ds[0]);
-
-      dusdlapl[1] = 1.0/(r.ds[1]*rho13[1]*rho13[1]);
-      dusdlapl[0] = 1.0/(r.ds[0]*rho13[0]*rho13[0]);
-
       dtsdn[1]    = -5.0*r.ts[1]/(3.0*r.ds[1]);
       dtsdn[0]    = -5.0*r.ts[0]/(3.0*r.ds[0]);
 
-      dtsdtau[1]  = dusdlapl[1];
-      dtsdtau[0]  = dusdlapl[0];
+      dtsdtau[1]  = 1.0/(r.ds[1]*rho13[1]*rho13[1]);
+      dtsdtau[0]  = 1.0/(r.ds[0]*rho13[0]*rho13[0]);
+
+      if(p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN){
+        dusdn[1]    = -5.0*r.us[1]/(3.0*r.ds[1]);
+        dusdn[0]    = -5.0*r.us[0]/(3.0*r.ds[0]);
+
+        dusdlapl[1] = dtsdtau[1];
+        dusdlapl[0] = dtsdtau[0];
+      }
+
     }else{
       dxsdn[0]    = M_CBRT2*dxt;
       dxsds[0]    = M_CBRT2*dxtds;
 
-      dusdn[0]    = -5.0*r.us[0]/(6.0*r.ds[0]);
-      dusdlapl[0] = 1.0/(2.0*r.ds[0]*rho13[0]*rho13[0]);
-      
       dtsdn[0]    = -5.0*r.ts[0]/(6.0*r.ds[0]);
-      dtsdtau[0]  = dusdlapl[0];
+      dtsdtau[0]  = 1.0/(2.0*r.ds[0]*rho13[0]*rho13[0]);
+
+      if(p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN){
+        dusdn[0]    = -5.0*r.us[0]/(6.0*r.ds[0]);
+        dusdlapl[0] = dtsdtau[0];
+      } 
     }
 
     if(vrho != NULL && (p->info->flags & XC_FLAGS_HAVE_VXC)){
@@ -148,24 +162,35 @@ work_mgga_c(const XC(func_type) *p, int np, const FLOAT *rho, const FLOAT *sigma
       vsigma[0] = r.dens*r.dfdxt*dxtds;
 
       if(p->nspin == XC_POLARIZED){
-	vrho[1]   = vrho[0] + r.dfdz*ndzdn[1] + r.dens*(r.dfdxs[1]*dxsdn[1] + r.dfdus[1]*dusdn[1] + r.dfdts[1]*dtsdn[1]);
-	vrho[0]   = vrho[0] + r.dfdz*ndzdn[0] + r.dens*(r.dfdxs[0]*dxsdn[0] + r.dfdus[0]*dusdn[0] + r.dfdts[0]*dtsdn[0]);
+	vrho[1]   = vrho[0] + r.dfdz*ndzdn[1] + r.dens*(r.dfdxs[1]*dxsdn[1] + r.dfdts[1]*dtsdn[1]);
+	vrho[0]   = vrho[0] + r.dfdz*ndzdn[0] + r.dens*(r.dfdxs[0]*dxsdn[0] + r.dfdts[0]*dtsdn[0]);
 
 	vsigma[2] = vsigma[0] + r.dens*r.dfdxs[1]*dxsds[1];
 	vsigma[1] = 2.0*vsigma[0];
 	vsigma[0] = vsigma[0] + r.dens*r.dfdxs[0]*dxsds[0];
 
-	vlapl[1]  = r.dens*r.dfdus[1]*dusdlapl[1];
-	vlapl[0]  = r.dens*r.dfdus[0]*dusdlapl[0];
+        if(p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN){
+          vrho[1]  += r.dens*r.dfdus[1]*dusdn[1];
+          vrho[0]  += r.dens*r.dfdus[0]*dusdn[0];
+
+          vlapl[1]  = r.dens*r.dfdus[1]*dusdlapl[1];
+          vlapl[0]  = r.dens*r.dfdus[0]*dusdlapl[0];
+        }
 
 	vtau[1]   = r.dens*r.dfdts[1]*dtsdtau[1];
 	vtau[0]   = r.dens*r.dfdts[0]*dtsdtau[0];
 	
       }else{
 	 /* factor of 2 comes from sum over sigma */
-	vrho[0]   += 2.0*r.dens*(r.dfdxs[0]*dxsdn[0] + r.dfdus[0]*dusdn[0] + r.dfdts[0]*dtsdn[0]);
+	vrho[0]   += 2.0*r.dens*(r.dfdxs[0]*dxsdn[0] + r.dfdts[0]*dtsdn[0]);
 	vsigma[0] += 2.0*r.dens*r.dfdxs[0]*dxsds[0];
-	vlapl[0]   = 2.0*r.dens*r.dfdus[0]*dusdlapl[0];
+
+        if(p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN){
+          vrho[0]   += 2.0*r.dens*r.dfdus[0]*dusdn[0];
+
+          vlapl[0]   = 2.0*r.dens*r.dfdus[0]*dusdlapl[0];
+        }
+
 	vtau[0]    = 2.0*r.dens*r.dfdts[0]*dtsdtau[0];
       }
     }
