@@ -23,32 +23,38 @@
   and of rho.
 ************************************************************************/
 
-#include <stdio.h>
-#include <string.h>
+
+/* WARNING Kinetic energy functionals are still not working */
+
 
 #ifndef XC_DIMENSIONS
 #  define XC_DIMENSIONS 3
 #endif
 
-static void 
-work_mgga_x(const XC(func_type) *p, int np,
-	    const FLOAT *rho, const FLOAT *sigma, const FLOAT *lapl, const FLOAT *tau,
-	    FLOAT *zk, FLOAT *vrho, FLOAT *vsigma, FLOAT *vlapl, FLOAT *vtau,
-	    FLOAT *v2rho2, FLOAT *v2sigma2, FLOAT *v2lapl2, FLOAT *v2tau2,
-	    FLOAT *v2rhosigma, FLOAT *v2rholapl, FLOAT *v2rhotau, 
-	    FLOAT *v2sigmalapl, FLOAT *v2sigmatau, FLOAT *v2lapltau)
+static void
+#ifdef XC_KINETIC_FUNCTIONAL
+work_mgga_k
+#else
+work_mgga_x
+#endif
+(const xc_func_type *p, int np,
+ const double *rho, const double *sigma, const double *lapl, const double *tau,
+ double *zk, double *vrho, double *vsigma, double *vlapl, double *vtau,
+ double *v2rho2, double *v2sigma2, double *v2lapl2, double *v2tau2,
+ double *v2rhosigma, double *v2rholapl, double *v2rhotau, 
+ double *v2sigmalapl, double *v2sigmatau, double *v2lapltau)
 {
-  XC(mgga_work_x_t) r;
-  FLOAT sfact, sfact2, dens, x_factor_c;
+  xc_mgga_work_x_t r;
+  double sfact, sfact2, x_factor_c, beta, dens;
+  double min_grad = p->dens_threshold;
   int is, ip;
-  int has_tail;
 
   /* WARNING: derivatives are _not_ OK for 2 dimensions */
 #if XC_DIMENSIONS == 2
-  const FLOAT cnst_rs = 1.0/M_SQRTPI;
+  const double cnst_rs = 1.0/M_SQRTPI;
   x_factor_c = X_FACTOR_2D_C;
 #else /* three dimensions */
-  const FLOAT cnst_rs = RS_FACTOR;
+  const double cnst_rs = RS_FACTOR;
   x_factor_c = X_FACTOR_C;
 #endif
 
@@ -63,44 +69,36 @@ work_mgga_x(const XC(func_type) *p, int np,
 
   sfact = (p->nspin == XC_POLARIZED) ? 1.0 : 2.0;
   sfact2 = sfact*sfact;
-
-  has_tail = 0;
-  switch(p->info->number){
-  case XC_MGGA_X_BR89:
-  case XC_MGGA_X_BJ06:
-  case XC_MGGA_X_TB09:
-  case XC_MGGA_X_RPP09:
-    has_tail = 1;
-    break;
-  }
   
   for(ip = 0; ip < np; ip++){
-    XC(rho2dzeta)(p->nspin, rho, &dens, &r.zeta);
+    xc_rho2dzeta(p->nspin, rho, &dens, &r.zeta);
 
-    if(dens < p->info->min_dens) goto end_ip_loop;
+    if(dens < p->dens_threshold) goto end_ip_loop;
 
-    r.rs = cnst_rs*POW(dens, -1.0/XC_DIMENSIONS);
+    r.rs = cnst_rs*pow(dens, -1.0/XC_DIMENSIONS);
 
     for(is=0; is<p->nspin; is++){
-      FLOAT lrho, rho1D, rho2pD_D, lsigma, gdm, lnr2, ltau;
+      double lrho, rho1D, rho2pD_D, lsigma, gdm, lnr2, ltau;
       int js = (is == 0) ? 0 : 2;
       int ls = (is == 0) ? 0 : 3;
       int ks = (is == 0) ? 0 : 5;
 
-      if((!has_tail && (rho[is] < p->info->min_dens || tau[is] < p->info->min_tau)) || (rho[is] == 0.0)) continue;
+      if (rho[is] < p->dens_threshold) continue;
 
-      lsigma= max(sigma[js]/sfact2, p->info->min_grad*p->info->min_grad);
-      gdm   = SQRT(lsigma);
+      lsigma= max(sigma[js]/sfact2, min_grad*min_grad);
+      gdm   = sqrt(lsigma);
       lrho  = rho[is]/sfact;
-      rho1D = POW(lrho, 1.0/XC_DIMENSIONS);
+      rho1D = pow(lrho, 1.0/XC_DIMENSIONS);
       rho2pD_D = lrho*rho1D*rho1D;
       r.x   = gdm/(lrho*rho1D);
     
       ltau  = tau[is]/sfact;
       r.t   = ltau/rho2pD_D;  /* tau/rho^((2+D)/D) */
 
-      lnr2  = lapl[is]/sfact; /* this can be negative */
-      r.u   = lnr2/rho2pD_D;  /* lapl/rho^((2+D)/D) */
+      if(p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN){
+        lnr2  = lapl[is]/sfact; /* this can be negative */
+        r.u   = lnr2/rho2pD_D;  /* lapl/rho^((2+D)/D) */
+      }
 
       func(p, &r);
 
@@ -112,9 +110,10 @@ work_mgga_x(const XC(func_type) *p, int np,
 
 	vtau[is]  = -x_factor_c*r.dfdt/rho1D;
 
-	vlapl[is] = -x_factor_c*r.dfdu/rho1D;
+        if(p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN)
+          vlapl[is] = -x_factor_c*r.dfdu/rho1D;
 
-	if(gdm>p->info->min_grad)
+	if(gdm>min_grad)
 	  vsigma[js] = -x_factor_c*(rho1D*lrho)*r.dfdx*r.x/(2.0*sfact*lsigma);
       }
 
@@ -124,28 +123,32 @@ work_mgga_x(const XC(func_type) *p, int np,
 	  (4.0*r.f - 4.0*r.x*r.dfdx + 4.0*4.0*r.x*r.x*r.d2fdx2 + 5.0*5.0*r.t*r.t*r.d2fdt2 + 5.0*5.0*r.u*r.u*r.d2fdu2 +
 	   2.0*5.0*(4.0*r.x*r.t*r.d2fdxt + 4.0*r.x*r.u*r.d2fdxu + 5.0*r.t*r.u*r.d2fdtu));
 
-	v2lapl2[js]   = -x_factor_c*r.d2fdu2/(sfact*rho1D*rho2pD_D);
-
 	v2tau2[js]    = -x_factor_c*r.d2fdt2/(sfact*rho1D*rho2pD_D);
 
-	v2rholapl[ls] = -x_factor_c*rho1D/(3.0*sfact*rho2pD_D)*
-	  (4.0*r.dfdu - 4.0*r.x*r.d2fdxu - 5.0*r.t*r.d2fdtu - 5.0*(r.dfdu + r.u*r.d2fdu2));
+        if(p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN){
+          v2lapl2[js]   = -x_factor_c*r.d2fdu2/(sfact*rho1D*rho2pD_D);
+
+          v2rholapl[ls] = -x_factor_c*rho1D/(3.0*sfact*rho2pD_D)*
+            (4.0*r.dfdu - 4.0*r.x*r.d2fdxu - 5.0*r.t*r.d2fdtu - 5.0*(r.dfdu + r.u*r.d2fdu2));
+
+          v2lapltau[ls] = -x_factor_c*r.d2fdtu/(rho1D*rho2pD_D);
+        }
 
 	v2rhotau[ls]  = -x_factor_c*rho1D/(3.0*sfact*rho2pD_D)*
 	  (4.0*r.dfdt - 4.0*r.x*r.d2fdxt - 5.0*r.u*r.d2fdtu - 5.0*(r.dfdt + r.t*r.d2fdt2));
 
-	v2lapltau[ls] = -x_factor_c*r.d2fdtu/(rho1D*rho2pD_D);
-
-	if(gdm > p->info->min_grad){
+	if(gdm > min_grad){
 	  v2sigma2[ks]    =  -x_factor_c*(rho1D*lrho)/(4.0*sfact2*sfact*lsigma*lsigma)*
 	    (r.d2fdx2*r.x*r.x - r.dfdx*r.x);
 
 	  v2rhosigma[ks]  = -x_factor_c*rho1D*r.x/(3.0*2.0*sfact2*lsigma)*
 	    (-4.0*r.x*r.d2fdx2 - 5.0*r.t*r.d2fdxt - 5.0*r.u*r.d2fdxu);
 
-	  v2sigmalapl[ks] = -x_factor_c*r.x/(2.0*sfact2*lsigma*rho1D)*r.d2fdxu;
+          if(p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN)
+            v2sigmalapl[ks] = -x_factor_c*r.x/(2.0*sfact2*lsigma*rho1D)*r.d2fdxu;
+
+          v2sigmatau[ks]  = -x_factor_c*r.x/(2.0*sfact2*lsigma*rho1D)*r.d2fdxt;
 
-	  v2sigmatau[ks]  = -x_factor_c*r.x/(2.0*sfact2*lsigma*rho1D)*r.d2fdxt;
 	}
       }
     }
