@@ -17,77 +17,22 @@
 */
 
 
-#include <stdlib.h>
-#include <stdio.h>
 #include <ctype.h>
-#include <string.h>
-#include "xc.h"
-
-const char *get_kind(const xc_func_type *func) {
-  switch(func->info->kind) {
-  case(XC_EXCHANGE):
-    return "XC_EXCHANGE";
-
-  case(XC_CORRELATION):
-    return "XC_CORRELATION";
-
-  case(XC_EXCHANGE_CORRELATION):
-   return "XC_EXCHANGE_CORRELATION";
-
-  case(XC_KINETIC):
-   return "XC_KINETIC";
-
-  default:
-    printf("Internal error in get_kind.\n");
-    return "";
-  }
-}
-
-const char *get_family(const xc_func_type *func) {
-  switch(func->info->family) {
-  case(XC_FAMILY_UNKNOWN):
-    return "XC_FAMILY_UNKNOWN";
-
-  case(XC_FAMILY_LDA):
-    return "XC_FAMILY_LDA";
-
-  case(XC_FAMILY_GGA):
-    return "XC_FAMILY_GGA";
-
-  case(XC_FAMILY_MGGA):
-    return "XC_FAMILY_MGGA";
-
-  case(XC_FAMILY_LCA):
-    return "XC_FAMILY_LCA";
-
-  case(XC_FAMILY_OEP):
-    return "XC_FAMILY_OEP";
-
-  case(XC_FAMILY_HYB_GGA):
-    return "XC_FAMILY_HYB_GGA";
-
-  case(XC_FAMILY_HYB_MGGA):
-    return "XC_FAMILY_HYB_MGGA";
-
-   default:
-    printf("Internal error in get_family.\n");
-    return "";
-  }
-}
+#include "util.h"
 
 int main(int argc, char **argv) {
+  int i, func_id, error;
+  xc_func_type func;
+  char *fname;
+
   if(argc!=2) {
     printf("Usage: %s [ func_id | func_name ]\n",argv[0]);
     return 1;
   }
 
-  int i, func_id, error;
-  xc_func_type func;
-  char *fname;
-
   /* Is functional defined by a string constant? */
   if(isalpha(argv[1][0]))
-    func_id = XC(functional_get_number)(argv[1]);
+    func_id = xc_functional_get_number(argv[1]);
   else
     func_id = atoi(argv[1]);
 
@@ -99,7 +44,7 @@ int main(int argc, char **argv) {
   }
 
   /* Get functional name */
-  fname = XC(functional_get_name)(func_id);
+  fname = xc_functional_get_name(func_id);
 
   /* Print out info */
   printf("%10s: %-20i\t%10s: %-25s\n","func_id", func_id, "name", fname);
@@ -121,11 +66,11 @@ int main(int argc, char **argv) {
 
     if(rangesep) {
       double alpha, beta, omega;
-      XC(hyb_cam_coef(&func,&omega,&alpha,&beta));
-      printf("\nThis is a range separated hybrid functional with range separation constant % .3f,\n",omega);
+      xc_hyb_cam_coef(&func,&omega,&alpha,&beta);
+      printf("\nThis is a range-separated hybrid functional with range-separation constant % .3f,\n",omega);
       printf("and %4.1f%% short-range and %4.1f%% long-range exact exchange.\n",(alpha+beta)*100,(alpha)*100);
     } else {
-      double alpha=XC(hyb_exx_coef(&func));
+      double alpha=xc_hyb_exx_coef(&func);
       printf("\nThis is a global hybrid functional with %4.1f%% of exact exchange.\n",alpha*100);
     }
   } else {
@@ -144,7 +89,7 @@ int main(int argc, char **argv) {
   }
 
   /* Free memory */
-  XC(func_end)(&func);
+  xc_func_end(&func);
   free(fname);
 
   return 0;
